.. include:: readme.rst

.. toctree::
    :hidden:
    :maxdepth: 2

    Overview <readme>

.. toctree::
    :maxdepth: 3
    :hidden:
    :titlesonly:

    dataformat
    benchmark
    API Reference <api/fibber>
    contributing
    authors
    history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
